## 🚀 Summary

What does this PR do?

---

## 🧪 What Changed?

- [ ] New feature
- [ ] Bug fix
- [ ] Documentation update
- [ ] Refactor / internal cleanup
- [ ] CI / tooling

---

## ✅ Checklist

- [ ] I've run all tests (`pytest`)
- [ ] I've run all pre-commit hooks (`pre-commit run --all-files`)
- [ ] I've added or updated tests
- [ ] I've updated docs or docstrings if needed
- [ ] I've added type hints (where applicable)
- [ ] My code follows the project style (Ruff, formatting, etc.)
- [ ] This PR targets the `main` branch

---

## 🔍 Related Issues

Closes #

---

## 📝 Notes for Reviewers (optional)
